window.Gleam.initSearch([{"doc":"gleither","title":"gleither","content":"# Gleither ↔️\n\nA small data-structure for representing an Either Monad. Written in the excellent [gleam ✨](https://gleam.run/) language. Supporting both Erlang &amp; Javascript targets\n\n[![test](https://github.com/bwireman/gleither/actions/workflows/test.yml/badge.svg)](https://github.com/bwireman/gleither/actions/workflows/test.yml)\n[![commits](https://img.shields.io/github/last-commit/bwireman/gleither)](https://github.com/bwireman/gleither/commit/main)\n[![mit](https://img.shields.io/github/license/bwireman/gleither?color=brightgreen)](https://github.com/bwireman/gleither/blob/main/LICENSE)\n[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen)](http://makeapullrequest.com)\n\nDocs: https://hexdocs.pm/gleither/\n\n```sh\ngleam add gleither\n```\n```gleam\nimport gleither.{Left, Right, map, get}\n\npub fn main() {\n  Right(1)\n  |&gt; map(fn(x) { x + 1 })\n  |&gt; get()\n  // Some(2)\n}\n\nfn ex() {\n  Left(1)\n  |&gt; map(fn(x) { x + 1 })\n  |&gt; get()\n  // Some(1)\n}\n```\n","url":"index.html"},{"doc":"gleither","title":"Either","content":"pub type Either(left, right) {\n  Left(val: left)\n  Right(val: right)\n}\n Monad representing a Left or Right\nLeft(val: left)\n left\n\nRight(val: right)\n right\n\nSynonyms:\ngleither.Either\ngleither Either","url":"gleither.html#Either"},{"doc":"gleither","title":"flat_map","content":"pub fn flat_map(\n  either: Either(a, b),\n  func: fn(b) -&gt; Either(a, b),\n) -&gt; Either(a, b)\n alias for flat_map_right\nSynonyms:\ngleither.flat_map\ngleither flat_map","url":"gleither.html#flat_map"},{"doc":"gleither","title":"flat_map_left","content":"pub fn flat_map_left(\n  either: Either(a, b),\n  func: fn(a) -&gt; Either(a, b),\n) -&gt; Either(a, b)\n map and flatten a Left\nSynonyms:\ngleither.flat_map_left\ngleither flat_map_left","url":"gleither.html#flat_map_left"},{"doc":"gleither","title":"flat_map_right","content":"pub fn flat_map_right(\n  either: Either(a, b),\n  func: fn(b) -&gt; Either(a, b),\n) -&gt; Either(a, b)\n map and flatten a Right\nSynonyms:\ngleither.flat_map_right\ngleither flat_map_right","url":"gleither.html#flat_map_right"},{"doc":"gleither","title":"flatten","content":"pub fn flatten(either: Either(a, Either(a, b))) -&gt; Either(a, b)\n alias for flatten_right\nSynonyms:\ngleither.flatten\ngleither flatten","url":"gleither.html#flatten"},{"doc":"gleither","title":"flatten_left","content":"pub fn flatten_left(\n  either: Either(Either(a, b), b),\n) -&gt; Either(a, b)\n flatten a nested Left\nSynonyms:\ngleither.flatten_left\ngleither flatten_left","url":"gleither.html#flatten_left"},{"doc":"gleither","title":"flatten_right","content":"pub fn flatten_right(\n  either: Either(a, Either(a, b)),\n) -&gt; Either(a, b)\n flatten a nested Right\nSynonyms:\ngleither.flatten_right\ngleither flatten_right","url":"gleither.html#flatten_right"},{"doc":"gleither","title":"from_result","content":"pub fn from_result(result: Result(a, b)) -&gt; Either(a, b)\n Convert a Result to an Either, mapping Ok to Left and Error to Right\nSynonyms:\ngleither.from_result\ngleither from_result","url":"gleither.html#from_result"},{"doc":"gleither","title":"full_flat_map","content":"pub fn full_flat_map(\n  either: Either(a, b),\n  left_func: fn(a) -&gt; Either(a, b),\n  right_func: fn(b) -&gt; Either(a, b),\n) -&gt; Either(a, b)\n flat_map either potential value\nSynonyms:\ngleither.full_flat_map\ngleither full_flat_map","url":"gleither.html#full_flat_map"},{"doc":"gleither","title":"full_map","content":"pub fn full_map(\n  either: Either(a, b),\n  left_func: fn(a) -&gt; c,\n  right_func: fn(b) -&gt; d,\n) -&gt; Either(c, d)\n map either potential value\nSynonyms:\ngleither.full_map\ngleither full_map","url":"gleither.html#full_map"},{"doc":"gleither","title":"get","content":"pub fn get(either: Either(a, b)) -&gt; Option(b)\n alias for get_right\nSynonyms:\ngleither.get\ngleither get","url":"gleither.html#get"},{"doc":"gleither","title":"get_left","content":"pub fn get_left(either: Either(a, b)) -&gt; Option(a)\n get the value of a Left or None\nSynonyms:\ngleither.get_left\ngleither get_left","url":"gleither.html#get_left"},{"doc":"gleither","title":"get_left_with_default","content":"pub fn get_left_with_default(\n  either: Either(a, b),\n  default: a,\n) -&gt; a\n get the value of a Left or default\nSynonyms:\ngleither.get_left_with_default\ngleither get_left_with_default","url":"gleither.html#get_left_with_default"},{"doc":"gleither","title":"get_right","content":"pub fn get_right(either: Either(a, b)) -&gt; Option(b)\n get the value of a Right or None\nSynonyms:\ngleither.get_right\ngleither get_right","url":"gleither.html#get_right"},{"doc":"gleither","title":"get_right_with_default","content":"pub fn get_right_with_default(\n  either: Either(a, b),\n  default: b,\n) -&gt; b\n get the value of a Right or default\nSynonyms:\ngleither.get_right_with_default\ngleither get_right_with_default","url":"gleither.html#get_right_with_default"},{"doc":"gleither","title":"get_with_default","content":"pub fn get_with_default(either: Either(a, b), default: b) -&gt; b\n alias for get_right_with_default\nSynonyms:\ngleither.get_with_default\ngleither get_with_default","url":"gleither.html#get_with_default"},{"doc":"gleither","title":"is_left","content":"pub fn is_left(either: Either(a, b)) -&gt; Bool\n Returns True if the supplied value is a Left\nSynonyms:\ngleither.is_left\ngleither is_left","url":"gleither.html#is_left"},{"doc":"gleither","title":"is_right","content":"pub fn is_right(either: Either(a, b)) -&gt; Bool\n Returns True if the supplied value is a Right\nSynonyms:\ngleither.is_right\ngleither is_right","url":"gleither.html#is_right"},{"doc":"gleither","title":"map","content":"pub fn map(\n  either: Either(a, b),\n  func: fn(b) -&gt; c,\n) -&gt; Either(a, c)\n alias for map_right\nSynonyms:\ngleither.map\ngleither map","url":"gleither.html#map"},{"doc":"gleither","title":"map_left","content":"pub fn map_left(\n  either: Either(a, b),\n  func: fn(a) -&gt; c,\n) -&gt; Either(c, b)\n apply a function to the Left or preserve the Right\nSynonyms:\ngleither.map_left\ngleither map_left","url":"gleither.html#map_left"},{"doc":"gleither","title":"map_right","content":"pub fn map_right(\n  either: Either(a, b),\n  func: fn(b) -&gt; c,\n) -&gt; Either(a, c)\n apply a function to the Right or preserve the Left\nSynonyms:\ngleither.map_right\ngleither map_right","url":"gleither.html#map_right"},{"doc":"gleither","title":"swap","content":"pub fn swap(either: Either(a, b)) -&gt; Either(b, a)\n Convert a Left to a Right and vice versa\nSynonyms:\ngleither.swap\ngleither swap","url":"gleither.html#swap"},{"doc":"gleither","title":"gleither","content":"","url":"gleither.html"}]);